@@ -1,5 +1,7 @@
 """A module to do analyses of k9 data"""
 
-__version__ = "0.4.4"
+__version__ = "0.5.0"
 from .count_burrows_detection import *  # noqa
 from .write_maya_nests_table import *  # noqa
+from .ReportingEffort import *  # noqa
+from .group_effort_and_distance import *  # noqa
